/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.ScreenShot2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef SCREENSHOT2INTERFACE_H
#define SCREENSHOT2INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KWin.ScreenShot2
 */
class OrgKdeKWinScreenShot2Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KWin.ScreenShot2"; }

public:
    OrgKdeKWinScreenShot2Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKWinScreenShot2Interface();

    Q_PROPERTY(uint Version READ version)
    inline uint version() const
    { return qvariant_cast< uint >(property("Version")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QVariantMap> CaptureActiveScreen(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureActiveScreen"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureActiveWindow(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureActiveWindow"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureArea(int x, int y, uint width, uint height, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y) << QVariant::fromValue(width) << QVariant::fromValue(height) << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureArea"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureInteractive(uint kind, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(kind) << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureInteractive"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureScreen(const QString &name, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name) << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureScreen"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureWindow(const QString &handle, const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(handle) << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureWindow"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> CaptureWorkspace(const QVariantMap &options, const QDBusUnixFileDescriptor &pipe)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(options) << QVariant::fromValue(pipe);
        return asyncCallWithArgumentList(QStringLiteral("CaptureWorkspace"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace KWin {
      using ScreenShot2 = ::OrgKdeKWinScreenShot2Interface;
    }
  }
}

#endif
