#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _org_kde_plasma_private_mobileshell_ActionDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ActionDrawerOpenSurface_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ActionDrawerWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_AppLaunch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BaseItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_Constants_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_Flickable_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_FlickableOpacityGradient_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_GridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_HapticsEffect_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_MarqueeLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_PanelBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ScreenEdgeDragEffect_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_StartupFeedbackPanelFill_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_StartupFeedbackWindows_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_TextDropShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VelocityCalculator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_AudioInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BatteryInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BluetoothInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NetworkInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_SignalStrengthInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BlurEffect_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_DeviceLock_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_HomeScreen_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_WallpaperSelector_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_GesturePanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NavigationPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NavigationPanelAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NavigationPanelButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ActionButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ActionButtonsProvider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_RotationButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationPopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationPopupManager_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationPopupProvider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_PulseAudio_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_KScreenOSDProvider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_AudioApplet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_DeviceListItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_icon_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ListItemBase_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_PopupCard_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_StreamListItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VolumeChangedPopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VolumeOSD_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VolumeOSDProvider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VolumeSlider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_PopupProviderLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BatteryIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BluetoothIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_InternetIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_SignalStrengthIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_VolumeIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ClockText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_StatusBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_KRunnerScreen_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BlurredBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_MediaControlsSource_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_MediaControlsWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_BaseNotificationItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationBodyLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationCard_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationEditContextMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationFooterActions_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationGroupHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationJobDetails_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationJobItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationPopupItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationReplyField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationsModelType_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationsUtils_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationsWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_NotificationTimeText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_ThumbnailStrip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_BrightnessItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_Handle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettings_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsFullDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsMinimizedDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsPanel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_ContentContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_LandscapeContentContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_NotificationDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _org_kde_plasma_private_mobileshell_actiondrawer_private_PortraitContentContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ActionDrawer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ActionDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ActionDrawerOpenSurface.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ActionDrawerOpenSurface_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ActionDrawerWindow.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ActionDrawerWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/AppLaunch.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_AppLaunch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BaseItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BaseItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/Constants.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_Constants_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/Flickable.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_Flickable_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/FlickableOpacityGradient.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_FlickableOpacityGradient_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/GridView.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_GridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/HapticsEffect.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_HapticsEffect_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ListView.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/MarqueeLabel.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_MarqueeLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/PanelBackground.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_PanelBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ScreenEdgeDragEffect.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ScreenEdgeDragEffect_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/StartupFeedbackPanelFill.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_StartupFeedbackPanelFill_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/StartupFeedbackWindows.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_StartupFeedbackWindows_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/TextDropShadow.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_TextDropShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VelocityCalculator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VelocityCalculator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/AudioInfo.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_AudioInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BatteryInfo.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BatteryInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BluetoothInfo.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BluetoothInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NetworkInfo.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NetworkInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/SignalStrengthInfo.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_SignalStrengthInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BlurEffect.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BlurEffect_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/DeviceLock.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_DeviceLock_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/HomeScreen.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_HomeScreen_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/WallpaperSelector.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_WallpaperSelector_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/GesturePanel.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_GesturePanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NavigationPanel.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NavigationPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NavigationPanelAction.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NavigationPanelAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NavigationPanelButton.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NavigationPanelButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ActionButton.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ActionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ActionButtonsProvider.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ActionButtonsProvider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/RotationButton.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_RotationButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationPopup.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationPopup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationPopupManager.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationPopupManager_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationPopupProvider.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationPopupProvider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/PulseAudio.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_PulseAudio_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/KScreenOSDProvider.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_KScreenOSDProvider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/AudioApplet.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_AudioApplet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/DeviceListItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_DeviceListItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/icon.js"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_icon_js::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ListItemBase.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ListItemBase_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/PopupCard.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_PopupCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/StreamListItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_StreamListItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VolumeChangedPopup.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VolumeChangedPopup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VolumeOSD.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VolumeOSD_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VolumeOSDProvider.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VolumeOSDProvider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VolumeSlider.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VolumeSlider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/PopupProviderLoader.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_PopupProviderLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BatteryIndicator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BatteryIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BluetoothIndicator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BluetoothIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/InternetIndicator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_InternetIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/SignalStrengthIndicator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_SignalStrengthIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/VolumeIndicator.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_VolumeIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ClockText.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ClockText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/StatusBar.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_StatusBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/KRunnerScreen.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_KRunnerScreen_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BlurredBackground.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BlurredBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/MediaControlsSource.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_MediaControlsSource_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/MediaControlsWidget.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_MediaControlsWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/BaseNotificationItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_BaseNotificationItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationBodyLabel.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationBodyLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationCard.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationEditContextMenu.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationEditContextMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationFooterActions.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationFooterActions_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationGroupHeader.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationGroupHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationJobDetails.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationJobDetails_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationJobItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationJobItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationPopupItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationPopupItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationReplyField.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationReplyField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationsModelType.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationsModelType_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationsUtils.js"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationsUtils_js::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationsWidget.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationsWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/NotificationTimeText.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_NotificationTimeText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/ThumbnailStrip.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_ThumbnailStrip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/BrightnessItem.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_BrightnessItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/Handle.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_Handle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettings.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettings_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettingsDelegate.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettingsDrawer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettingsFullDelegate.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsFullDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettingsMinimizedDelegate.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsMinimizedDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/QuickSettingsPanel.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_QuickSettingsPanel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/ContentContainer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_ContentContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/LandscapeContentContainer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_LandscapeContentContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/NotificationDrawer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_NotificationDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/org/kde/plasma/private/mobileshell/actiondrawer/private/PortraitContentContainer.qml"), &QmlCacheGeneratedCode::_org_kde_plasma_private_mobileshell_actiondrawer_private_PortraitContentContainer_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_mobileshellplugin)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_mobileshellplugin))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_mobileshellplugin)() {
    return 1;
}
