/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.sigxcpu.Feedback.Haptic.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef HAPTICINTERFACE_H
#define HAPTICINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "vibrationevent.h"

/*
 * Proxy class for interface org.sigxcpu.Feedback.Haptic
 */
class OrgSigxcpuFeedbackHapticInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.sigxcpu.Feedback.Haptic"; }

public:
    OrgSigxcpuFeedbackHapticInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgSigxcpuFeedbackHapticInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> Vibrate(const QString &app_id, VibrationEventList pattern)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(app_id) << QVariant::fromValue(pattern);
        return asyncCallWithArgumentList(QStringLiteral("Vibrate"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace sigxcpu {
    namespace Feedback {
      using Haptic = ::OrgSigxcpuFeedbackHapticInterface;
    }
  }
}

#endif
