// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "waydroidintegrationplugin_debug.h"


Q_LOGGING_CATEGORY(WAYDROIDINTEGRATIONPLUGIN, "org.kde.plasma.private.mobileshell.waydroidintegrationplugin", QtInfoMsg)

