/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.Panels.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PANELSADAPTOR_H
#define PANELSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "/build/plasma-mobile/src/plasma-mobile-6.7.3/components/mobileshellstate/panelsettingsdbusobjectmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.plasmashellMobilePanels
 */
class PlasmashellMobilePanelsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmashellMobilePanels")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.plasmashellMobilePanels\">\n"
"    <signal name=\"statusBarHeightChanged\"/>\n"
"    <signal name=\"statusBarLeftPaddingChanged\"/>\n"
"    <signal name=\"statusBarRightPaddingChanged\"/>\n"
"    <signal name=\"statusBarCenterSpacingChanged\"/>\n"
"    <signal name=\"navigationPanelHeightChanged\"/>\n"
"    <signal name=\"navigationPanelLeftPaddingChanged\"/>\n"
"    <signal name=\"navigationPanelRightPaddingChanged\"/>\n"
"    <method name=\"statusBarHeight\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"statusBarLeftPadding\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"statusBarRightPadding\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"statusBarCenterSpacing\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"navigationPanelHeight\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"navigationPanelLeftPadding\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"navigationPanelRightPadding\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    PlasmashellMobilePanelsAdaptor(PanelSettingsDBusObject *parent);
    ~PlasmashellMobilePanelsAdaptor() override;

    inline PanelSettingsDBusObject *parent() const
    { return static_cast<PanelSettingsDBusObject *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    double navigationPanelHeight();
    double navigationPanelLeftPadding();
    double navigationPanelRightPadding();
    double statusBarCenterSpacing();
    double statusBarHeight();
    double statusBarLeftPadding();
    double statusBarRightPadding();
Q_SIGNALS: // SIGNALS
    void navigationPanelHeightChanged();
    void navigationPanelLeftPaddingChanged();
    void navigationPanelRightPaddingChanged();
    void statusBarCenterSpacingChanged();
    void statusBarHeightChanged();
    void statusBarLeftPaddingChanged();
    void statusBarRightPaddingChanged();
};

#endif
