/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Waydroid.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "waydroidadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WaydroidAdaptor
 */

WaydroidAdaptor::WaydroidAdaptor(WaydroidDBusObject *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WaydroidAdaptor::~WaydroidAdaptor()
{
    // destructor
}

QString WaydroidAdaptor::androidId()
{
    // handle method call org.kde.plasmashell.Waydroid.androidId
    return parent()->androidId();
}

QList<QDBusObjectPath> WaydroidAdaptor::applications()
{
    // handle method call org.kde.plasmashell.Waydroid.applications
    return parent()->applications();
}

void WaydroidAdaptor::deleteApplication(const QString &appId)
{
    // handle method call org.kde.plasmashell.Waydroid.deleteApplication
    parent()->deleteApplication(appId);
}

void WaydroidAdaptor::initialize(int systemType, int romType)
{
    // handle method call org.kde.plasmashell.Waydroid.initialize
    parent()->initialize(systemType, romType);
}

void WaydroidAdaptor::initialize(int systemType, int romType, bool forced)
{
    // handle method call org.kde.plasmashell.Waydroid.initialize
    parent()->initialize(systemType, romType, forced);
}

void WaydroidAdaptor::installApk(const QString &apkFile)
{
    // handle method call org.kde.plasmashell.Waydroid.installApk
    parent()->installApk(apkFile);
}

QString WaydroidAdaptor::ipAddress()
{
    // handle method call org.kde.plasmashell.Waydroid.ipAddress
    return parent()->ipAddress();
}

bool WaydroidAdaptor::multiWindows()
{
    // handle method call org.kde.plasmashell.Waydroid.multiWindows
    return parent()->multiWindows();
}

void WaydroidAdaptor::refreshAndroidId()
{
    // handle method call org.kde.plasmashell.Waydroid.refreshAndroidId
    parent()->refreshAndroidId();
}

void WaydroidAdaptor::refreshApplications()
{
    // handle method call org.kde.plasmashell.Waydroid.refreshApplications
    parent()->refreshApplications();
}

void WaydroidAdaptor::refreshSessionInfo()
{
    // handle method call org.kde.plasmashell.Waydroid.refreshSessionInfo
    parent()->refreshSessionInfo();
}

void WaydroidAdaptor::resetWaydroid()
{
    // handle method call org.kde.plasmashell.Waydroid.resetWaydroid
    parent()->resetWaydroid();
}

int WaydroidAdaptor::sessionStatus()
{
    // handle method call org.kde.plasmashell.Waydroid.sessionStatus
    return parent()->sessionStatus();
}

void WaydroidAdaptor::setMultiWindows(bool multiWindows)
{
    // handle method call org.kde.plasmashell.Waydroid.setMultiWindows
    parent()->setMultiWindows(multiWindows);
}

void WaydroidAdaptor::setSuspend(bool suspend)
{
    // handle method call org.kde.plasmashell.Waydroid.setSuspend
    parent()->setSuspend(suspend);
}

void WaydroidAdaptor::setUevent(bool uevent)
{
    // handle method call org.kde.plasmashell.Waydroid.setUevent
    parent()->setUevent(uevent);
}

void WaydroidAdaptor::startSession()
{
    // handle method call org.kde.plasmashell.Waydroid.startSession
    parent()->startSession();
}

int WaydroidAdaptor::status()
{
    // handle method call org.kde.plasmashell.Waydroid.status
    return parent()->status();
}

void WaydroidAdaptor::stopSession()
{
    // handle method call org.kde.plasmashell.Waydroid.stopSession
    parent()->stopSession();
}

bool WaydroidAdaptor::suspend()
{
    // handle method call org.kde.plasmashell.Waydroid.suspend
    return parent()->suspend();
}

int WaydroidAdaptor::systemType()
{
    // handle method call org.kde.plasmashell.Waydroid.systemType
    return parent()->systemType();
}

bool WaydroidAdaptor::uevent()
{
    // handle method call org.kde.plasmashell.Waydroid.uevent
    return parent()->uevent();
}


#include "moc_waydroidadaptor.cpp"
