// This file was generated by qtwaylandscanner
// source file is kde-lockscreen-overlay-v1.xml

#include "qwayland-kde-lockscreen-overlay-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    kde_lockscreen_overlay_v1::kde_lockscreen_overlay_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_lockscreen_overlay_v1::kde_lockscreen_overlay_v1(struct ::kde_lockscreen_overlay_v1 *obj)
        : m_kde_lockscreen_overlay_v1(obj)
    {
    }

    kde_lockscreen_overlay_v1::kde_lockscreen_overlay_v1()
        : m_kde_lockscreen_overlay_v1(nullptr)
    {
    }

    kde_lockscreen_overlay_v1::~kde_lockscreen_overlay_v1()
    {
    }

    void kde_lockscreen_overlay_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_lockscreen_overlay_v1 = static_cast<struct ::kde_lockscreen_overlay_v1 *>(wlRegistryBind(registry, id, &kde_lockscreen_overlay_v1_interface, version));
    }

    void kde_lockscreen_overlay_v1::init(struct ::kde_lockscreen_overlay_v1 *obj)
    {
        m_kde_lockscreen_overlay_v1 = obj;
    }

    kde_lockscreen_overlay_v1 *kde_lockscreen_overlay_v1::fromObject(struct ::kde_lockscreen_overlay_v1 *object)
    {
        return static_cast<kde_lockscreen_overlay_v1 *>(kde_lockscreen_overlay_v1_get_user_data(object));
    }

    bool kde_lockscreen_overlay_v1::isInitialized() const
    {
        return m_kde_lockscreen_overlay_v1 != nullptr;
    }

    uint32_t kde_lockscreen_overlay_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_lockscreen_overlay_v1));
    }

    const struct wl_interface *kde_lockscreen_overlay_v1::interface()
    {
        return &::kde_lockscreen_overlay_v1_interface;
    }

    void kde_lockscreen_overlay_v1::allow(struct ::wl_surface *surface)
    {
        ::kde_lockscreen_overlay_v1_allow(
            m_kde_lockscreen_overlay_v1,
            surface);
    }

    void kde_lockscreen_overlay_v1::destroy()
    {
        ::kde_lockscreen_overlay_v1_destroy(
            m_kde_lockscreen_overlay_v1);
        m_kde_lockscreen_overlay_v1 = nullptr;
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
