/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef PLASMASHELLMOBILEINTERFACE_H
#define PLASMASHELLMOBILEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.plasmashell
 */
class OrgKdePlasmashellInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.plasmashell"; }

public:
    OrgKdePlasmashellInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdePlasmashellInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> closeActionDrawer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("closeActionDrawer"), argumentList);
    }

    inline QDBusPendingReply<bool> doNotDisturb()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("doNotDisturb"), argumentList);
    }

    inline QDBusPendingReply<bool> isActionDrawerOpen()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isActionDrawerOpen"), argumentList);
    }

    inline QDBusPendingReply<bool> isNotificationPopupDrawerOpen()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isNotificationPopupDrawerOpen"), argumentList);
    }

    inline QDBusPendingReply<bool> isTaskSwitcherVisible()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isTaskSwitcherVisible"), argumentList);
    }

    inline QDBusPendingReply<bool> isVolumeOSDOpen()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isVolumeOSDOpen"), argumentList);
    }

    inline QDBusPendingReply<> openActionDrawer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("openActionDrawer"), argumentList);
    }

    inline QDBusPendingReply<> openAppLaunchAnimationWithPosition(int screen, const QString &splashIcon, const QString &title, const QString &storageId, double x, double y, double sourceIconSize)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(screen) << QVariant::fromValue(splashIcon) << QVariant::fromValue(title) << QVariant::fromValue(storageId) << QVariant::fromValue(x) << QVariant::fromValue(y) << QVariant::fromValue(sourceIconSize);
        return asyncCallWithArgumentList(QStringLiteral("openAppLaunchAnimationWithPosition"), argumentList);
    }

    inline QDBusPendingReply<> openHomeScreen()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("openHomeScreen"), argumentList);
    }

    inline QDBusPendingReply<> openLockScreenKeypad()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("openLockScreenKeypad"), argumentList);
    }

    inline QDBusPendingReply<QString> panelState()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("panelState"), argumentList);
    }

    inline QDBusPendingReply<> resetHomeScreenPosition()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetHomeScreenPosition"), argumentList);
    }

    inline QDBusPendingReply<> setDoNotDisturb(bool value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setDoNotDisturb"), argumentList);
    }

    inline QDBusPendingReply<> setIsActionDrawerOpen(bool value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setIsActionDrawerOpen"), argumentList);
    }

    inline QDBusPendingReply<> setIsNotificationPopupDrawerOpen(bool value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setIsNotificationPopupDrawerOpen"), argumentList);
    }

    inline QDBusPendingReply<> setIsTaskSwitcherVisible(bool value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setIsTaskSwitcherVisible"), argumentList);
    }

    inline QDBusPendingReply<> setIsVolumeOSDOpen(bool value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setIsVolumeOSDOpen"), argumentList);
    }

    inline QDBusPendingReply<> setPanelState(const QString &state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("setPanelState"), argumentList);
    }

    inline QDBusPendingReply<> showVolumeOSD()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showVolumeOSD"), argumentList);
    }

    inline QDBusPendingReply<> triggerAppLaunchMaximizePanelAnimation(int screen, const QString &color)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(screen) << QVariant::fromValue(color);
        return asyncCallWithArgumentList(QStringLiteral("triggerAppLaunchMaximizePanelAnimation"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void appLaunchMaximizePanelAnimationTriggered(int screen, const QString &color);
    void closeActionDrawerRequested();
    void doNotDisturbChanged();
    void isActionDrawerOpenChanged();
    void isNotificationPopupDrawerOpenChanged();
    void isTaskSwitcherVisibleChanged();
    void isVolumeOSDOpenChanged();
    void openActionDrawerRequested();
    void openHomeScreenRequested();
    void openLockScreenKeypadRequested();
    void panelStateChanged();
    void resetHomeScreenPositionRequested();
    void showVolumeOSDRequested();
};

namespace org {
  namespace kde {
    using plasmashell = ::OrgKdePlasmashellInterface;
  }
}

#endif
