// This file was generated by qtwaylandscanner
// source file is kde-lockscreen-overlay-v1.xml

#ifndef QT_WAYLAND_KDE_LOCKSCREEN_OVERLAY_V1
#define QT_WAYLAND_KDE_LOCKSCREEN_OVERLAY_V1

#include "wayland-kde-lockscreen-overlay-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  kde_lockscreen_overlay_v1
    {
    public:
        kde_lockscreen_overlay_v1(struct ::wl_registry *registry, uint32_t id, int version);
        kde_lockscreen_overlay_v1(struct ::kde_lockscreen_overlay_v1 *object);
        kde_lockscreen_overlay_v1();

        virtual ~kde_lockscreen_overlay_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::kde_lockscreen_overlay_v1 *object);

        struct ::kde_lockscreen_overlay_v1 *object() { return m_kde_lockscreen_overlay_v1; }
        const struct ::kde_lockscreen_overlay_v1 *object() const { return m_kde_lockscreen_overlay_v1; }
        static kde_lockscreen_overlay_v1 *fromObject(struct ::kde_lockscreen_overlay_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_invalid_surface_state = 0, // the client provided an invalid surface state
        };

        void allow(struct ::wl_surface *surface);
        void destroy();

    private:
        struct ::kde_lockscreen_overlay_v1 *m_kde_lockscreen_overlay_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
