/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Waydroid.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef WAYDROIDADAPTOR_H
#define WAYDROIDADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "/build/plasma-mobile/src/plasma-mobile-6.7.3/components/waydroidintegrationplugin/waydroiddbusobject.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.plasmashell.Waydroid
 */
class WaydroidAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmashell.Waydroid")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.plasmashell.Waydroid\">\n"
"    <signal name=\"statusChanged\"/>\n"
"    <signal name=\"downloadStatusChanged\">\n"
"      <arg direction=\"out\" type=\"d\" name=\"downloaded\"/>\n"
"      <arg direction=\"out\" type=\"d\" name=\"total\"/>\n"
"      <arg direction=\"out\" type=\"d\" name=\"speed\"/>\n"
"    </signal>\n"
"    <signal name=\"sessionStatusChanged\"/>\n"
"    <signal name=\"systemTypeChanged\"/>\n"
"    <signal name=\"ipAddressChanged\"/>\n"
"    <signal name=\"androidIdChanged\"/>\n"
"    <signal name=\"multiWindowsChanged\"/>\n"
"    <signal name=\"suspendChanged\"/>\n"
"    <signal name=\"ueventChanged\"/>\n"
"    <signal name=\"applicationAdded\">\n"
"      <arg direction=\"out\" type=\"o\" name=\"path\"/>\n"
"    </signal>\n"
"    <signal name=\"applicationRemoved\">\n"
"      <arg direction=\"out\" type=\"o\" name=\"path\"/>\n"
"    </signal>\n"
"    <signal name=\"actionFinished\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"actionFailed\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"errorOccurred\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"title\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <method name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"sessionStatus\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"systemType\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"ipAddress\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"androidId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"multiWindows\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setMultiWindows\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"multiWindows\"/>\n"
"    </method>\n"
"    <method name=\"suspend\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSuspend\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"suspend\"/>\n"
"    </method>\n"
"    <method name=\"uevent\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUevent\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"uevent\"/>\n"
"    </method>\n"
"    <method name=\"applications\">\n"
"      <arg direction=\"out\" type=\"ao\"/>\n"
"    </method>\n"
"    <method name=\"initialize\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"systemType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"romType\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"forced\"/>\n"
"    </method>\n"
"    <method name=\"initialize\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"systemType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"romType\"/>\n"
"    </method>\n"
"    <method name=\"startSession\"/>\n"
"    <method name=\"stopSession\"/>\n"
"    <method name=\"resetWaydroid\"/>\n"
"    <method name=\"installApk\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"apkFile\"/>\n"
"    </method>\n"
"    <method name=\"deleteApplication\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"appId\"/>\n"
"    </method>\n"
"    <method name=\"refreshSessionInfo\"/>\n"
"    <method name=\"refreshAndroidId\"/>\n"
"    <method name=\"refreshApplications\"/>\n"
"  </interface>\n"
        "")
public:
    WaydroidAdaptor(WaydroidDBusObject *parent);
    ~WaydroidAdaptor() override;

    inline WaydroidDBusObject *parent() const
    { return static_cast<WaydroidDBusObject *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString androidId();
    QList<QDBusObjectPath> applications();
    void deleteApplication(const QString &appId);
    void initialize(int systemType, int romType);
    void initialize(int systemType, int romType, bool forced);
    void installApk(const QString &apkFile);
    QString ipAddress();
    bool multiWindows();
    void refreshAndroidId();
    void refreshApplications();
    void refreshSessionInfo();
    void resetWaydroid();
    int sessionStatus();
    void setMultiWindows(bool multiWindows);
    void setSuspend(bool suspend);
    void setUevent(bool uevent);
    void startSession();
    int status();
    void stopSession();
    bool suspend();
    int systemType();
    bool uevent();
Q_SIGNALS: // SIGNALS
    void actionFailed(const QString &message);
    void actionFinished(const QString &message);
    void androidIdChanged();
    void applicationAdded(const QDBusObjectPath &path);
    void applicationRemoved(const QDBusObjectPath &path);
    void downloadStatusChanged(double downloaded, double total, double speed);
    void errorOccurred(const QString &title, const QString &message);
    void ipAddressChanged();
    void multiWindowsChanged();
    void sessionStatusChanged();
    void statusChanged();
    void suspendChanged();
    void systemTypeChanged();
    void ueventChanged();
};

#endif
