/* Generated by wayland-scanner 1.25.0 */

/*
 * SPDX-FileCopyrightText: 2022 Aleix Pol Gonzalez <aleixpol@kde.org>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface wl_surface_interface;

static const struct wl_interface *kde_lockscreen_overlay_v1_types[] = {
	&wl_surface_interface,
};

static const struct wl_message kde_lockscreen_overlay_v1_requests[] = {
	{ "allow", "o", kde_lockscreen_overlay_v1_types + 0 },
	{ "destroy", "", kde_lockscreen_overlay_v1_types + 0 },
};

WL_EXPORT const struct wl_interface kde_lockscreen_overlay_v1_interface = {
	"kde_lockscreen_overlay_v1", 1,
	2, kde_lockscreen_overlay_v1_requests,
	0, NULL,
};

