/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.BrightnessControl.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BRIGHTNESSCONTROLINTERFACE_H
#define BRIGHTNESSCONTROLINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Solid.PowerManagement.Actions.BrightnessControl
 */
class OrgKdeSolidPowerManagementActionsBrightnessControlInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Solid.PowerManagement.Actions.BrightnessControl"; }

public:
    OrgKdeSolidPowerManagementActionsBrightnessControlInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeSolidPowerManagementActionsBrightnessControlInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<int> brightness()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("brightness"), argumentList);
    }

    inline QDBusPendingReply<int> brightnessMax()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("brightnessMax"), argumentList);
    }

    inline QDBusPendingReply<int> brightnessSteps()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("brightnessSteps"), argumentList);
    }

    inline QDBusPendingReply<> setBrightness(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setBrightness"), argumentList);
    }

    inline QDBusPendingReply<> setBrightnessSilent(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setBrightnessSilent"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void brightnessChanged(int in0);
    void brightnessMaxChanged(int in0);
};

namespace org {
  namespace kde {
    namespace Solid {
      namespace PowerManagement {
        namespace Actions {
          using BrightnessControl = ::OrgKdeSolidPowerManagementActionsBrightnessControlInterface;
        }
      }
    }
  }
}

#endif
