#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawerGrid_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawerHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_DelegateDragItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_DelegateDropArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FavouritesBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolderView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolderViewTitle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolioHomeScreen_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_HomeScreenPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_HomeScreenPages_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_PlaceholderDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_WidgetDragItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_config_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AbstractDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AppDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AppFolderDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateAppIcon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateFolderIcon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateIconLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_KeyboardHighlight_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_WidgetDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_WidgetDelegateConfig_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_ConfirmDeleteFolderDialogLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_ContextMenuLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_DarkenEffect_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_Orientation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetHandlePosition_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetResizeHandle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetResizeHandleFrame_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_AppletListDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_AppletListViewer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_SettingsButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_SettingsComponent_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_ConfigGeneral_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/AppDrawer.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/AppDrawerGrid.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawerGrid_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/AppDrawerHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_AppDrawerHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/DelegateDragItem.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_DelegateDragItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/DelegateDropArea.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_DelegateDropArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/FavouritesBar.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FavouritesBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/FolderView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolderView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/FolderViewTitle.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolderViewTitle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/FolioHomeScreen.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_FolioHomeScreen_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/HomeScreenPage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_HomeScreenPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/HomeScreenPages.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_HomeScreenPages_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/main.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/PlaceholderDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_PlaceholderDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/WidgetDragItem.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_WidgetDragItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/config.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_config_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/AbstractDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AbstractDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/AppDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AppDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/AppFolderDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_AppFolderDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/DelegateAppIcon.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateAppIcon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/DelegateFolderIcon.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateFolderIcon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/DelegateIconLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateIconLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/DelegateLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/DelegateShadow.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_DelegateShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/KeyboardHighlight.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_KeyboardHighlight_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/WidgetDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_WidgetDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/delegate/WidgetDelegateConfig.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_delegate_WidgetDelegateConfig_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/ConfirmDeleteFolderDialogLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_ConfirmDeleteFolderDialogLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/ContextMenuLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_ContextMenuLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/DarkenEffect.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_DarkenEffect_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/Orientation.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_Orientation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/WidgetHandlePosition.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetHandlePosition_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/WidgetResizeHandle.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetResizeHandle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/private/WidgetResizeHandleFrame.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_private_WidgetResizeHandleFrame_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/settings/AppletListDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_AppletListDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/settings/AppletListViewer.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_AppletListViewer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/settings/SettingsButton.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_SettingsButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/settings/SettingsComponent.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_SettingsComponent_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/settings/ConfigGeneral.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_mobile_homescreen_folio_settings_ConfigGeneral_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma_mobile_homescreen)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma_mobile_homescreen))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_org_kde_plasma_mobile_homescreen)() {
    return 1;
}
