/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x20,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xb2,0x6,0xb5,0x10,0x0,0xe6,0x95,0x40,0x1e,0x30,0x73,0x73,
  0x3f,0xa3,0x25,0x82,0x56,0xd6,0xfa,0xd6,0xb6,0xbc,0xf1,0x89,0xef,0xfe,0xfd,0xed,
  0xfe,0x5f,0xf8,0xff,0x94,0xa9,0x18,0xa,0x95,0x81,0x2a,0x38,0x0,0x37,0x0,0x39,
  0x0,0x11,0x63,0x8c,0x31,0xc6,0x58,0x73,0x18,0x41,0xe2,0x57,0x67,0x19,0x4d,0x68,
  0x71,0x26,0x69,0xab,0xf8,0x2e,0x41,0x1d,0xed,0x83,0x5b,0x4d,0xf1,0x67,0x6a,0xde,
  0x5a,0xcd,0x74,0xf8,0x32,0x6b,0x4d,0x6f,0x9b,0xc9,0xf1,0x4e,0x7d,0x28,0xa5,0x4e,
  0x6a,0x4d,0x85,0x52,0x3a,0xbc,0xda,0x5a,0x1,0xa7,0x14,0x4a,0xe6,0xbc,0x53,0x49,
  0xe5,0xd6,0x32,0xf6,0x1d,0xf6,0xb3,0x78,0xfe,0x2e,0xfc,0x6,0x97,0xd5,0x30,0xdf,
  0x8f,0xaf,0xed,0xa8,0x42,0xcf,0x5,0xb9,0xd6,0xbb,0xe1,0xde,0xea,0xe,0x8f,0x68,
  0x7a,0x46,0x7b,0xbc,0x90,0x0,0x93,0x60,0x10,0x90,0xf8,0x1e,0x65,0x84,0x94,0x85,
  0x4d,0xbd,0xaa,0x12,0xf1,0x1b,0xd6,0x2b,0x1e,0xd2,0x9f,0x77,0xe7,0xb1,0x74,0xb,
  0xf5,0x21,0x2c,0x76,0xaf,0x8a,0x7b,0x68,0xa8,0x71,0x8f,0xd1,0x58,0x37,0x3,0xba,
  0xc3,0xb3,0x4d,0x35,0x15,0xf8,0x8c,0x3e,0xf8,0x4d,0xf7,0x11,0x97,0x6a,0xb0,0xd6,
  0x94,0x72,0xcf,0x4c,0xdf,0xb5,0x87,0xd1,0x4,0x51,0xb4,0xa1,0xde,0x35,0xe9,0x89,
  0x34,0x5b,0xbc,0x7c,0x83,0xca,0x8f,0x5f,0xb8,0x8e,0x8f,0x2b,0xad,0x3d,0xc4,0xed,
  0xbe,0xc,0x15,0x3e,0x9b,0x2e,0xbe,0xee,0xcf,0xf9,0x1e,0x96,0xb2,0xe2,0xa1,0x37,
  0x4f,0x79,0x73,0x25,0x87,0x2d,0x2a,0x23,0xee,0x6b,0xed,0xf8,0xc7,0x91,0x80,0x8a,
  0xa8,0x81,0x1a,0x11,0x92,0x92,0x24,0x5,0xa9,0x4c,0x7,0x40,0x84,0x10,0xe3,0xa6,
  0x3a,0x72,0x30,0x3c,0x10,0x25,0x11,0x8e,0x41,0x48,0x94,0x8b,0x89,0x5c,0xa8,0xa0,
  0xc9,0xc6,0x66,0xd2,0x0,0x13,0x6d,0x36,0xdb,0x10,0xe2,0x4f,0x6e,0x46,0x43,0x29,
  0xd9,0x18,0x21,0x62,0x78,0x58,0xa7,0xf3,0xf7,0x4f,0x38,0xe2,0xba,0x8,0xa1,0x9,
  0x84,0x1d,0x23,0x8f,0xd7,0x92,0x6f,0xa,0x1c,0xbe,0x2f,0xb9,0x7b,0x96,0xc5,0xfc,
  0x6d,0x5a,0xdb,0x3e,0xe9,0xd1,0xbd,0x8f,0x75,0xeb,0xf5,0xd9,0x39,0xa1,0x61,0x20,
  0x7d,0xc0,0x4e,0x8e,0xc7,0xd5,0x6a,0xf1,0x74,0x2a,0xf0,0x72,0x5a,0xd8,0x5,0x61,
  0x1a,0x9b,0xc7,0xc0,0x7d,0x3a,0xd6,0x5,0x1a,0x87,0x17,0x50,0x97,0xfa,0xcf,0x25,
  0x2f,0x2e,0x93,0x71,0x98,0x26,0x61,0xd0,0x4c,0xca,0xa,0x6a,0xbd,0xed,0x81,0x2b,
  0x84,0xb2,0x89,0xf2,0x2f,0xda,0x9c,0x28,0xba,0xd9,0x17,0xa9,0x70,0x32,0x1c,0x66,
  0xe0,0x89,0xf,0xf4,0x7,0x95,0xba,0x94,0x8b,0x66,0x75,0x0,0x40,0x87,0xad,0xa2,
  0xcb,0x35,0x84,0xe5,0x11,0x2a,0xbe,0x7b,0xeb,0xbd,0xb3,0xa8,0xf6,0x81,0xe0,0x30,
  0x26,0x9a,0x40,0x1d,0x5d,0x18,0x88,0xc8,0xf2,0x8b,0xe3,0xac,0xc0,0x70,0x40,0x3d,
  0xda,0x64,0x62,0x91,0x3a,0xee,0xd4,0x10,0x23,0x4b,0xab,0xb,0x4,0xd3,0xc5,0xd9,
  0xe8,0x3f,0x57,0xcb,0xea,0x64,0x3b,0xf3,0xd6,0x93,0xb6,0xd9,0xa8,0x89,0x39,0xae,
  0x65,0xb,0x6d,0xd9,0x63,0x56,0xa3,0xf9,0x9b,0xc1,0xb3,0x66,0x5a,0x9c,0x7d,0x3f,
  0x3,0xee,0x6c,0xd7,0xc1,0x8c,0xac,0x3e,0x3d,0xe7,0x5d,0x95,0xa5,0xa7,0x6,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // applet
  0x0,0x6,
  0x6,0x87,0x72,0xc4,
  0x0,0x61,
  0x0,0x70,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // mobile
  0x0,0x6,
  0x7,0x45,0x90,0x25,
  0x0,0x6d,
  0x0,0x6f,0x0,0x62,0x0,0x69,0x0,0x6c,0x0,0x65,
    // homescreen
  0x0,0xa,
  0xc,0x97,0x67,0xde,
  0x0,0x68,
  0x0,0x6f,0x0,0x6d,0x0,0x65,0x0,0x73,0x0,0x63,0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6e,
    // folio
  0x0,0x5,
  0x0,0x6d,0x62,0xff,
  0x0,0x66,
  0x0,0x6f,0x0,0x6c,0x0,0x69,0x0,0x6f,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x8,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde/plasma/mobile
  0x0,0x0,0x0,0x52,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen
  0x0,0x0,0x0,0x64,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xa,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio
  0x0,0x0,0x0,0x7e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xb,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,
  // :/qt/qml/plasma/applet/org/kde/plasma/mobile/homescreen/folio/qmldir
  0x0,0x0,0x0,0x8e,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x65,0x75,0x12,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_plasma_applet_org_kde_plasma_mobile_homescreen_folio)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
