/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MOBILEADAPTOR_H
#define MOBILEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "/build/plasma-mobile/src/plasma-mobile-6.7.3/components/mobileshellstate/shelldbusobject.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.plasmashell
 */
class PlasmashellAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmashell")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.plasmashell\">\n"
"    <signal name=\"doNotDisturbChanged\"/>\n"
"    <signal name=\"isActionDrawerOpenChanged\"/>\n"
"    <signal name=\"isVolumeOSDOpenChanged\"/>\n"
"    <signal name=\"isNotificationPopupDrawerOpenChanged\"/>\n"
"    <signal name=\"panelStateChanged\"/>\n"
"    <signal name=\"isTaskSwitcherVisibleChanged\"/>\n"
"    <signal name=\"openActionDrawerRequested\"/>\n"
"    <signal name=\"closeActionDrawerRequested\"/>\n"
"    <signal name=\"appLaunchMaximizePanelAnimationTriggered\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"screen\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"color\"/>\n"
"    </signal>\n"
"    <signal name=\"openHomeScreenRequested\"/>\n"
"    <signal name=\"resetHomeScreenPositionRequested\"/>\n"
"    <signal name=\"showVolumeOSDRequested\"/>\n"
"    <signal name=\"openLockScreenKeypadRequested\"/>\n"
"    <method name=\"doNotDisturb\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setDoNotDisturb\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"isActionDrawerOpen\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIsActionDrawerOpen\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"isVolumeOSDOpen\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIsVolumeOSDOpen\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"isNotificationPopupDrawerOpen\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIsNotificationPopupDrawerOpen\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"panelState\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setPanelState\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"state\"/>\n"
"    </method>\n"
"    <method name=\"isTaskSwitcherVisible\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIsTaskSwitcherVisible\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"openActionDrawer\"/>\n"
"    <method name=\"closeActionDrawer\"/>\n"
"    <method name=\"openAppLaunchAnimationWithPosition\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"screen\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"splashIcon\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"title\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"storageId\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"x\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"y\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"sourceIconSize\"/>\n"
"    </method>\n"
"    <method name=\"triggerAppLaunchMaximizePanelAnimation\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"screen\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"color\"/>\n"
"    </method>\n"
"    <method name=\"openHomeScreen\"/>\n"
"    <method name=\"resetHomeScreenPosition\"/>\n"
"    <method name=\"showVolumeOSD\"/>\n"
"    <method name=\"openLockScreenKeypad\"/>\n"
"  </interface>\n"
        "")
public:
    PlasmashellAdaptor(ShellDBusObject *parent);
    ~PlasmashellAdaptor() override;

    inline ShellDBusObject *parent() const
    { return static_cast<ShellDBusObject *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void closeActionDrawer();
    bool doNotDisturb();
    bool isActionDrawerOpen();
    bool isNotificationPopupDrawerOpen();
    bool isTaskSwitcherVisible();
    bool isVolumeOSDOpen();
    void openActionDrawer();
    void openAppLaunchAnimationWithPosition(int screen, const QString &splashIcon, const QString &title, const QString &storageId, double x, double y, double sourceIconSize);
    void openHomeScreen();
    void openLockScreenKeypad();
    QString panelState();
    void resetHomeScreenPosition();
    void setDoNotDisturb(bool value);
    void setIsActionDrawerOpen(bool value);
    void setIsNotificationPopupDrawerOpen(bool value);
    void setIsTaskSwitcherVisible(bool value);
    void setIsVolumeOSDOpen(bool value);
    void setPanelState(const QString &state);
    void showVolumeOSD();
    void triggerAppLaunchMaximizePanelAnimation(int screen, const QString &color);
Q_SIGNALS: // SIGNALS
    void appLaunchMaximizePanelAnimationTriggered(int screen, const QString &color);
    void closeActionDrawerRequested();
    void doNotDisturbChanged();
    void isActionDrawerOpenChanged();
    void isNotificationPopupDrawerOpenChanged();
    void isTaskSwitcherVisibleChanged();
    void isVolumeOSDOpenChanged();
    void openActionDrawerRequested();
    void openHomeScreenRequested();
    void openLockScreenKeypadRequested();
    void panelStateChanged();
    void resetHomeScreenPositionRequested();
    void showVolumeOSDRequested();
};

#endif
