/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.Panels.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "panelsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PlasmashellMobilePanelsAdaptor
 */

PlasmashellMobilePanelsAdaptor::PlasmashellMobilePanelsAdaptor(PanelSettingsDBusObject *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PlasmashellMobilePanelsAdaptor::~PlasmashellMobilePanelsAdaptor()
{
    // destructor
}

double PlasmashellMobilePanelsAdaptor::navigationPanelHeight()
{
    // handle method call org.kde.plasmashellMobilePanels.navigationPanelHeight
    return parent()->navigationPanelHeight();
}

double PlasmashellMobilePanelsAdaptor::navigationPanelLeftPadding()
{
    // handle method call org.kde.plasmashellMobilePanels.navigationPanelLeftPadding
    return parent()->navigationPanelLeftPadding();
}

double PlasmashellMobilePanelsAdaptor::navigationPanelRightPadding()
{
    // handle method call org.kde.plasmashellMobilePanels.navigationPanelRightPadding
    return parent()->navigationPanelRightPadding();
}

double PlasmashellMobilePanelsAdaptor::statusBarCenterSpacing()
{
    // handle method call org.kde.plasmashellMobilePanels.statusBarCenterSpacing
    return parent()->statusBarCenterSpacing();
}

double PlasmashellMobilePanelsAdaptor::statusBarHeight()
{
    // handle method call org.kde.plasmashellMobilePanels.statusBarHeight
    return parent()->statusBarHeight();
}

double PlasmashellMobilePanelsAdaptor::statusBarLeftPadding()
{
    // handle method call org.kde.plasmashellMobilePanels.statusBarLeftPadding
    return parent()->statusBarLeftPadding();
}

double PlasmashellMobilePanelsAdaptor::statusBarRightPadding()
{
    // handle method call org.kde.plasmashellMobilePanels.statusBarRightPadding
    return parent()->statusBarRightPadding();
}


#include "moc_panelsadaptor.cpp"
