/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mobileadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PlasmashellAdaptor
 */

PlasmashellAdaptor::PlasmashellAdaptor(ShellDBusObject *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PlasmashellAdaptor::~PlasmashellAdaptor()
{
    // destructor
}

void PlasmashellAdaptor::closeActionDrawer()
{
    // handle method call org.kde.plasmashell.closeActionDrawer
    parent()->closeActionDrawer();
}

bool PlasmashellAdaptor::doNotDisturb()
{
    // handle method call org.kde.plasmashell.doNotDisturb
    return parent()->doNotDisturb();
}

bool PlasmashellAdaptor::isActionDrawerOpen()
{
    // handle method call org.kde.plasmashell.isActionDrawerOpen
    return parent()->isActionDrawerOpen();
}

bool PlasmashellAdaptor::isNotificationPopupDrawerOpen()
{
    // handle method call org.kde.plasmashell.isNotificationPopupDrawerOpen
    return parent()->isNotificationPopupDrawerOpen();
}

bool PlasmashellAdaptor::isTaskSwitcherVisible()
{
    // handle method call org.kde.plasmashell.isTaskSwitcherVisible
    return parent()->isTaskSwitcherVisible();
}

bool PlasmashellAdaptor::isVolumeOSDOpen()
{
    // handle method call org.kde.plasmashell.isVolumeOSDOpen
    return parent()->isVolumeOSDOpen();
}

void PlasmashellAdaptor::openActionDrawer()
{
    // handle method call org.kde.plasmashell.openActionDrawer
    parent()->openActionDrawer();
}

void PlasmashellAdaptor::openAppLaunchAnimationWithPosition(int screen, const QString &splashIcon, const QString &title, const QString &storageId, double x, double y, double sourceIconSize)
{
    // handle method call org.kde.plasmashell.openAppLaunchAnimationWithPosition
    parent()->openAppLaunchAnimationWithPosition(screen, splashIcon, title, storageId, x, y, sourceIconSize);
}

void PlasmashellAdaptor::openHomeScreen()
{
    // handle method call org.kde.plasmashell.openHomeScreen
    parent()->openHomeScreen();
}

void PlasmashellAdaptor::openLockScreenKeypad()
{
    // handle method call org.kde.plasmashell.openLockScreenKeypad
    parent()->openLockScreenKeypad();
}

QString PlasmashellAdaptor::panelState()
{
    // handle method call org.kde.plasmashell.panelState
    return parent()->panelState();
}

void PlasmashellAdaptor::resetHomeScreenPosition()
{
    // handle method call org.kde.plasmashell.resetHomeScreenPosition
    parent()->resetHomeScreenPosition();
}

void PlasmashellAdaptor::setDoNotDisturb(bool value)
{
    // handle method call org.kde.plasmashell.setDoNotDisturb
    parent()->setDoNotDisturb(value);
}

void PlasmashellAdaptor::setIsActionDrawerOpen(bool value)
{
    // handle method call org.kde.plasmashell.setIsActionDrawerOpen
    parent()->setIsActionDrawerOpen(value);
}

void PlasmashellAdaptor::setIsNotificationPopupDrawerOpen(bool value)
{
    // handle method call org.kde.plasmashell.setIsNotificationPopupDrawerOpen
    parent()->setIsNotificationPopupDrawerOpen(value);
}

void PlasmashellAdaptor::setIsTaskSwitcherVisible(bool value)
{
    // handle method call org.kde.plasmashell.setIsTaskSwitcherVisible
    parent()->setIsTaskSwitcherVisible(value);
}

void PlasmashellAdaptor::setIsVolumeOSDOpen(bool value)
{
    // handle method call org.kde.plasmashell.setIsVolumeOSDOpen
    parent()->setIsVolumeOSDOpen(value);
}

void PlasmashellAdaptor::setPanelState(const QString &state)
{
    // handle method call org.kde.plasmashell.setPanelState
    parent()->setPanelState(state);
}

void PlasmashellAdaptor::showVolumeOSD()
{
    // handle method call org.kde.plasmashell.showVolumeOSD
    parent()->showVolumeOSD();
}

void PlasmashellAdaptor::triggerAppLaunchMaximizePanelAnimation(int screen, const QString &color)
{
    // handle method call org.kde.plasmashell.triggerAppLaunchMaximizePanelAnimation
    parent()->triggerAppLaunchMaximizePanelAnimation(screen, color);
}


#include "moc_mobileadaptor.cpp"
