/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.NightLight.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef NIGHTLIGHTINTERFACE_H
#define NIGHTLIGHTINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KWin.NightLight
 */
class OrgKdeKWinNightLightInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KWin.NightLight"; }

public:
    OrgKdeKWinNightLightInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKWinNightLightInterface();

    Q_PROPERTY(bool available READ available)
    inline bool available() const
    { return qvariant_cast< bool >(property("available")); }

    Q_PROPERTY(uint currentTemperature READ currentTemperature)
    inline uint currentTemperature() const
    { return qvariant_cast< uint >(property("currentTemperature")); }

    Q_PROPERTY(bool daylight READ daylight)
    inline bool daylight() const
    { return qvariant_cast< bool >(property("daylight")); }

    Q_PROPERTY(bool enabled READ enabled)
    inline bool enabled() const
    { return qvariant_cast< bool >(property("enabled")); }

    Q_PROPERTY(bool inhibited READ inhibited)
    inline bool inhibited() const
    { return qvariant_cast< bool >(property("inhibited")); }

    Q_PROPERTY(uint mode READ mode)
    inline uint mode() const
    { return qvariant_cast< uint >(property("mode")); }

    Q_PROPERTY(qulonglong previousTransitionDateTime READ previousTransitionDateTime)
    inline qulonglong previousTransitionDateTime() const
    { return qvariant_cast< qulonglong >(property("previousTransitionDateTime")); }

    Q_PROPERTY(uint previousTransitionDuration READ previousTransitionDuration)
    inline uint previousTransitionDuration() const
    { return qvariant_cast< uint >(property("previousTransitionDuration")); }

    Q_PROPERTY(bool running READ running)
    inline bool running() const
    { return qvariant_cast< bool >(property("running")); }

    Q_PROPERTY(qulonglong scheduledTransitionDateTime READ scheduledTransitionDateTime)
    inline qulonglong scheduledTransitionDateTime() const
    { return qvariant_cast< qulonglong >(property("scheduledTransitionDateTime")); }

    Q_PROPERTY(uint scheduledTransitionDuration READ scheduledTransitionDuration)
    inline uint scheduledTransitionDuration() const
    { return qvariant_cast< uint >(property("scheduledTransitionDuration")); }

    Q_PROPERTY(uint targetTemperature READ targetTemperature)
    inline uint targetTemperature() const
    { return qvariant_cast< uint >(property("targetTemperature")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<uint> inhibit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("inhibit"), argumentList);
    }

    inline QDBusPendingReply<> preview(uint temperature)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(temperature);
        return asyncCallWithArgumentList(QStringLiteral("preview"), argumentList);
    }

    inline QDBusPendingReply<> stopPreview()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("stopPreview"), argumentList);
    }

    inline QDBusPendingReply<> uninhibit(uint cookie)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(cookie);
        return asyncCallWithArgumentList(QStringLiteral("uninhibit"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

#endif
