/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.WaydroidApplication.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "waydroidapplicationadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WaydroidApplicationAdaptor
 */

WaydroidApplicationAdaptor::WaydroidApplicationAdaptor(WaydroidApplicationDBusObject *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WaydroidApplicationAdaptor::~WaydroidApplicationAdaptor()
{
    // destructor
}

QString WaydroidApplicationAdaptor::name()
{
    // handle method call org.kde.plasmashell.WaydroidApplication.name
    return parent()->name();
}

QString WaydroidApplicationAdaptor::packageName()
{
    // handle method call org.kde.plasmashell.WaydroidApplication.packageName
    return parent()->packageName();
}


#include "moc_waydroidapplicationadaptor.cpp"
