// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "flashlighthelper_debug.h"


Q_LOGGING_CATEGORY(FLASHLIGHTHELPER, "org.kde.plasma.mobileshell.flashlighthelper", QtInfoMsg)

