/****************************************************************************
** Meta object code from reading C++ file 'tests.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-mobile-6.7.3/tests/notificationtest/tests.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tests.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16NotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN16NotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationTest, qt_meta_tag_ZN16NotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16NotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16NotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16NotificationTestE_t>.metaTypes,
    nullptr
} };

void NotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *NotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16NotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21BasicNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto BasicNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN21BasicNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BasicNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BasicNotificationTest, qt_meta_tag_ZN21BasicNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BasicNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21BasicNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21BasicNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21BasicNotificationTestE_t>.metaTypes,
    nullptr
} };

void BasicNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BasicNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *BasicNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BasicNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21BasicNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int BasicNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19UrlNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto UrlNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN19UrlNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UrlNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UrlNotificationTest, qt_meta_tag_ZN19UrlNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UrlNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UrlNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UrlNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UrlNotificationTestE_t>.metaTypes,
    nullptr
} };

void UrlNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UrlNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UrlNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UrlNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UrlNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int UrlNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21ReplyNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto ReplyNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN21ReplyNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReplyNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReplyNotificationTest, qt_meta_tag_ZN21ReplyNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReplyNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReplyNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReplyNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ReplyNotificationTestE_t>.metaTypes,
    nullptr
} };

void ReplyNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReplyNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ReplyNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReplyNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReplyNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int ReplyNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN26LowUrgencyNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto LowUrgencyNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LowUrgencyNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LowUrgencyNotificationTest, qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LowUrgencyNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>.metaTypes,
    nullptr
} };

void LowUrgencyNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LowUrgencyNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *LowUrgencyNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LowUrgencyNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LowUrgencyNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int LowUrgencyNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN27HighUrgencyNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto HighUrgencyNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HighUrgencyNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HighUrgencyNotificationTest, qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HighUrgencyNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>.metaTypes,
    nullptr
} };

void HighUrgencyNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HighUrgencyNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *HighUrgencyNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HighUrgencyNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27HighUrgencyNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int HighUrgencyNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto CriticalUrgencyNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CriticalUrgencyNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CriticalUrgencyNotificationTest, qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CriticalUrgencyNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>.metaTypes,
    nullptr
} };

void CriticalUrgencyNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CriticalUrgencyNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CriticalUrgencyNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CriticalUrgencyNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31CriticalUrgencyNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int CriticalUrgencyNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7FakeJobE_t {};
} // unnamed namespace

template <> constexpr inline auto FakeJob::qt_create_metaobjectdata<qt_meta_tag_ZN7FakeJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FakeJob",
        "timerFinished",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'timerFinished'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FakeJob, qt_meta_tag_ZN7FakeJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FakeJob::staticMetaObject = { {
    QMetaObject::SuperData::link<KJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FakeJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FakeJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7FakeJobE_t>.metaTypes,
    nullptr
} };

void FakeJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timerFinished(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *FakeJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FakeJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FakeJobE_t>.strings))
        return static_cast<void*>(this);
    return KJob::qt_metacast(_clname);
}

int FakeJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN19JobNotificationTestE_t {};
} // unnamed namespace

template <> constexpr inline auto JobNotificationTest::qt_create_metaobjectdata<qt_meta_tag_ZN19JobNotificationTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JobNotificationTest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JobNotificationTest, qt_meta_tag_ZN19JobNotificationTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject JobNotificationTest::staticMetaObject = { {
    QMetaObject::SuperData::link<NotificationTest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JobNotificationTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JobNotificationTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19JobNotificationTestE_t>.metaTypes,
    nullptr
} };

void JobNotificationTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobNotificationTest *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *JobNotificationTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JobNotificationTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JobNotificationTestE_t>.strings))
        return static_cast<void*>(this);
    return NotificationTest::qt_metacast(_clname);
}

int JobNotificationTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationTest::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
