// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "waydroidhelper_debug.h"


Q_LOGGING_CATEGORY(WAYDROIDHELPER, "org.kde.plasma.mobileshell.waydroidhelper", QtInfoMsg)

