/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.Mobile.Panels.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef PLASMASHELLMOBILEPANELSINTERFACE_H
#define PLASMASHELLMOBILEPANELSINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.plasmashellMobilePanels
 */
class OrgKdePlasmashellMobilePanelsInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.plasmashellMobilePanels"; }

public:
    OrgKdePlasmashellMobilePanelsInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdePlasmashellMobilePanelsInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<double> navigationPanelHeight()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("navigationPanelHeight"), argumentList);
    }

    inline QDBusPendingReply<double> navigationPanelLeftPadding()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("navigationPanelLeftPadding"), argumentList);
    }

    inline QDBusPendingReply<double> navigationPanelRightPadding()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("navigationPanelRightPadding"), argumentList);
    }

    inline QDBusPendingReply<double> statusBarCenterSpacing()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("statusBarCenterSpacing"), argumentList);
    }

    inline QDBusPendingReply<double> statusBarHeight()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("statusBarHeight"), argumentList);
    }

    inline QDBusPendingReply<double> statusBarLeftPadding()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("statusBarLeftPadding"), argumentList);
    }

    inline QDBusPendingReply<double> statusBarRightPadding()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("statusBarRightPadding"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void navigationPanelHeightChanged();
    void navigationPanelLeftPaddingChanged();
    void navigationPanelRightPaddingChanged();
    void statusBarCenterSpacingChanged();
    void statusBarHeightChanged();
    void statusBarLeftPaddingChanged();
    void statusBarRightPaddingChanged();
};

namespace org {
  namespace kde {
    using plasmashellMobilePanels = ::OrgKdePlasmashellMobilePanelsInterface;
  }
}

#endif
